.. _homogenization-linear_homogenization_postproc:

homogenization/linear_homogenization_postproc.py
================================================

**Description**


This example shows how to use the VTK postprocessing functions.




:download:`source code </../sfepy/examples/homogenization/linear_homogenization_postproc.py>`

.. literalinclude:: /../sfepy/examples/homogenization/linear_homogenization_postproc.py

